@@ -143,13 +143,13 @@ func (p Pin) configure(config PinConfig, signal uint32) {
 // outFunc returns the FUNCx_OUT_SEL_CFG register used for configuring the
 // output function selection.
 func (p Pin) outFunc() *volatile.Register32 {
-	return (*volatile.Register32)(unsafe.Pointer((uintptr(unsafe.Pointer(&esp.GPIO.FUNC0_OUT_SEL_CFG)) + uintptr(p)*4)))
+	return (*volatile.Register32)(unsafe.Add(unsafe.Pointer(&esp.GPIO.FUNC0_OUT_SEL_CFG), uintptr(p)*4))
 }
 
 // inFunc returns the FUNCy_IN_SEL_CFG register used for configuring the input
 // function selection.
 func inFunc(signal uint32) *volatile.Register32 {
-	return (*volatile.Register32)(unsafe.Pointer((uintptr(unsafe.Pointer(&esp.GPIO.FUNC0_IN_SEL_CFG)) + uintptr(signal)*4)))
+	return (*volatile.Register32)(unsafe.Add(unsafe.Pointer(&esp.GPIO.FUNC0_IN_SEL_CFG), uintptr(signal)*4))
 }
 
 // Set the pin to high or low.
@@ -237,13 +237,13 @@ func (p Pin) mux() *volatile.Register32 {
 	case 27:
 		return &esp.IO_MUX.GPIO27
 	case 14:
-		return &esp.IO_MUX.MTMS
+		return &esp.IO_MUX.GPIO14
 	case 12:
-		return &esp.IO_MUX.MTDI
+		return &esp.IO_MUX.GPIO12
 	case 13:
-		return &esp.IO_MUX.MTCK
+		return &esp.IO_MUX.GPIO13
 	case 15:
-		return &esp.IO_MUX.MTDO
+		return &esp.IO_MUX.GPIO15
 	case 2:
 		return &esp.IO_MUX.GPIO2
 	case 0:
@@ -255,17 +255,17 @@ func (p Pin) mux() *volatile.Register32 {
 	case 17:
 		return &esp.IO_MUX.GPIO17
 	case 9:
-		return &esp.IO_MUX.SD_DATA2
+		return &esp.IO_MUX.GPIO9
 	case 10:
-		return &esp.IO_MUX.SD_DATA3
+		return &esp.IO_MUX.GPIO10
 	case 11:
-		return &esp.IO_MUX.SD_CMD
+		return &esp.IO_MUX.GPIO11
 	case 6:
-		return &esp.IO_MUX.SD_CLK
+		return &esp.IO_MUX.GPIO6
 	case 7:
-		return &esp.IO_MUX.SD_DATA0
+		return &esp.IO_MUX.GPIO7
 	case 8:
-		return &esp.IO_MUX.SD_DATA1
+		return &esp.IO_MUX.GPIO8
 	case 5:
 		return &esp.IO_MUX.GPIO5
 	case 18:
@@ -279,9 +279,9 @@ func (p Pin) mux() *volatile.Register32 {
 	case 22:
 		return &esp.IO_MUX.GPIO22
 	case 3:
-		return &esp.IO_MUX.U0RXD
+		return &esp.IO_MUX.GPIO3
 	case 1:
-		return &esp.IO_MUX.U0TXD
+		return &esp.IO_MUX.GPIO1
 	case 23:
 		return &esp.IO_MUX.GPIO23
 	case 24:
@@ -314,16 +314,19 @@ func (uart *UART) Configure(config UARTConfig) {
 	uart.Bus.CLKDIV.Set(peripheralClock / config.BaudRate)
 }
 
-func (uart *UART) WriteByte(b byte) error {
+func (uart *UART) writeByte(b byte) error {
 	for (uart.Bus.STATUS.Get()>>16)&0xff >= 128 {
 		// Read UART_TXFIFO_CNT from the status register, which indicates how
 		// many bytes there are in the transmit buffer. Wait until there are
 		// less than 128 bytes in this buffer (the default buffer size).
 	}
-	uart.Bus.TX_FIFO.Set(b)
+	// Write to the TX_FIFO register.
+	(*volatile.Register8)(unsafe.Add(unsafe.Pointer(uart.Bus), 0x200C0000)).Set(b)
 	return nil
 }
 
+func (uart *UART) flush() {}
+
 // Serial Peripheral Interface on the ESP32.
 type SPI struct {
 	Bus *esp.SPI_Type
@@ -457,7 +460,7 @@ func (spi SPI) Transfer(w byte) (byte, error) {
 	return byte(spi.Bus.W0.Get()), nil
 }
 
-// Tx handles read/write operation for SPI interface. Since SPI is a syncronous write/read
+// Tx handles read/write operation for SPI interface. Since SPI is a synchronous write/read
 // interface, there must always be the same number of bytes written as bytes read.
 // This is accomplished by sending zero bits if r is bigger than w or discarding
 // the incoming data if w is bigger than r.
