@@ -24,7 +24,7 @@ var (
 // here: https://github.com/vmilea/pico_i2c_slave
 
 // Features: Taken from datasheet.
-// Default controller mode, with target mode available (not simulataneously).
+// Default controller mode, with target mode available (not simultaneously).
 // Default target address of RP2040: 0x055
 // Supports 10-bit addressing in controller mode
 // 16-element transmit buffer
@@ -36,7 +36,7 @@ var (
 // GPIO config
 // Each controller must connect its clock SCL and data SDA to one pair of GPIOs.
 // The I2C standard requires that drivers drivea signal low, or when not driven the signal will be pulled high.
-// This applies to SCL and SDA. The GPIO pads should beconfigured for:
+// This applies to SCL and SDA. The GPIO pads should be configured for:
 //  Pull-up enabled
 //  Slew rate limited
 //  Schmitt trigger enabled
@@ -348,7 +348,7 @@ func (i2c *I2C) tx(addr uint8, tx, rx []byte, timeout_us uint64) (err error) {
 		}
 		if abort || last {
 			// If the transaction was aborted or if it completed
-			// successfully wait until the STOP condition has occured.
+			// successfully wait until the STOP condition has occurred.
 
 			// TODO Could there be an abort while waiting for the STOP
 			// condition here? If so, additional code would be needed here
@@ -501,15 +501,23 @@ func (i2c *I2C) Reply(buf []byte) error {
 	}
 
 	for txPtr < len(buf) {
-		if stat&rp.I2C0_IC_INTR_MASK_M_TX_EMPTY != 0 {
-			i2c.Bus.IC_DATA_CMD.Set(uint32(buf[txPtr]))
+		if i2c.Bus.GetIC_RAW_INTR_STAT_TX_EMPTY() != 0 {
+			i2c.Bus.SetIC_DATA_CMD_DAT(uint32(buf[txPtr]))
 			txPtr++
+			// The DW_apb_i2c flushes/resets/empties the
+			// TX_FIFO and RX_FIFO whenever there is a transmit abort
+			// caused by any of the events tracked by the
+			// IC_TX_ABRT_SOURCE register.
+			// In other words, it's safe to block until TX FIFO is
+			// EMPTY--it will empty from being transmitted or on error.
+			for i2c.Bus.GetIC_RAW_INTR_STAT_TX_EMPTY() == 0 {
+			}
 		}
 
 		// This Tx abort is a normal case - we're sending more
 		// data than controller wants to receive
-		if stat&rp.I2C0_IC_INTR_MASK_M_TX_ABRT != 0 {
-			i2c.Bus.IC_CLR_TX_ABRT.Get()
+		if i2c.Bus.GetIC_RAW_INTR_STAT_TX_ABRT() != 0 {
+			i2c.Bus.GetIC_CLR_TX_ABRT_CLR_TX_ABRT()
 			return nil
 		}
 
