@@ -1,5 +1,4 @@
 //go:build gc.leaking
-// +build gc.leaking
 
 package runtime
 
@@ -45,7 +44,7 @@ func alloc(size uintptr, layout unsafe.Pointer) unsafe.Pointer {
 		runtimePanic("out of memory")
 	}
 	pointer := unsafe.Pointer(addr)
-	memzero(pointer, size)
+	zero_new_alloc(pointer, size)
 	return pointer
 }
 
@@ -65,16 +64,32 @@ func free(ptr unsafe.Pointer) {
 	// Memory is never freed.
 }
 
+// ReadMemStats populates m with memory statistics.
+//
+// The returned memory statistics are up to date as of the
+// call to ReadMemStats. This would not do GC implicitly for you.
+func ReadMemStats(m *MemStats) {
+	m.HeapIdle = 0
+	m.HeapInuse = gcTotalAlloc
+	m.HeapReleased = 0 // always 0, we don't currently release memory back to the OS.
+
+	m.HeapSys = m.HeapInuse + m.HeapIdle
+	m.GCSys = 0
+	m.TotalAlloc = gcTotalAlloc
+	m.Mallocs = gcMallocs
+	m.Frees = gcFrees
+	m.Sys = uint64(heapEnd - heapStart)
+	// no free -- current in use heap is the total allocated
+	m.HeapAlloc = gcTotalAlloc
+	m.Alloc = m.HeapAlloc
+}
+
 func GC() {
 	// No-op.
 }
 
-func KeepAlive(x interface{}) {
-	// Unimplemented. Only required with SetFinalizer().
-}
-
 func SetFinalizer(obj interface{}, finalizer interface{}) {
-	// Unimplemented.
+	// No-op.
 }
 
 func initHeap() {
@@ -88,7 +103,3 @@ func setHeapEnd(newHeapEnd uintptr) {
 	// enough.
 	heapEnd = newHeapEnd
 }
-
-func markRoots(start, end uintptr) {
-	// dummy, so that markGlobals will compile
-}
