@@ -1,4 +1,7 @@
-//go:build tinygo.wasm
+//go:build tinygo.wasm && !wasm_unknown && !wasip2
+
+// This file is for wasm/wasip1 and for wasm/js, which both use much of the
+// WASIp1 API.
 
 package runtime
 
@@ -12,17 +15,20 @@ type __wasi_iovec_t struct {
 	bufLen uint
 }
 
-//go:wasm-module wasi_snapshot_preview1
-//export fd_write
+//go:wasmimport wasi_snapshot_preview1 fd_write
 func fd_write(id uint32, iovs *__wasi_iovec_t, iovs_len uint, nwritten *uint) (errno uint)
 
 // See:
 // https://github.com/WebAssembly/WASI/blob/main/phases/snapshot/docs.md#-proc_exitrval-exitcode
 //
-//go:wasm-module wasi_snapshot_preview1
-//export proc_exit
+//go:wasmimport wasi_snapshot_preview1 proc_exit
 func proc_exit(exitcode uint32)
 
+// Flush stdio on exit.
+//
+//export __stdio_exit
+func __stdio_exit()
+
 const (
 	putcharBufferSize = 120
 	stdout            = 1
@@ -74,6 +80,9 @@ func abort() {
 
 //go:linkname syscall_Exit syscall.Exit
 func syscall_Exit(code int) {
+	// TODO: should we call __stdio_exit here?
+	// It's a low-level exit (syscall.Exit) so doing any libc stuff seems
+	// unexpected, but then where else should stdio buffers be flushed?
 	proc_exit(uint32(code))
 }
 
@@ -87,3 +96,14 @@ func procPin() {
 //go:linkname procUnpin sync/atomic.runtime_procUnpin
 func procUnpin() {
 }
+
+func hardwareRand() (n uint64, ok bool) {
+	n |= uint64(libc_arc4random())
+	n |= uint64(libc_arc4random()) << 32
+	return n, true
+}
+
+// uint32_t arc4random(void);
+//
+//export arc4random
+func libc_arc4random() uint32
