@@ -1,26 +1,9 @@
-//go:build wasm && !wasi
+//go:build wasm && !wasip1
 
 package runtime
 
-import "unsafe"
-
 type timeUnit float64 // time in milliseconds, just like Date.now() in JavaScript
 
-// wasmNested is used to detect scheduler nesting (WASM calls into JS calls back into WASM).
-// When this happens, we need to use a reduced version of the scheduler.
-var wasmNested bool
-
-//export _start
-func _start() {
-	// These need to be initialized early so that the heap can be initialized.
-	heapStart = uintptr(unsafe.Pointer(&heapStartSymbol))
-	heapEnd = uintptr(wasm_memory_size(0) * wasmPageSize)
-
-	wasmNested = true
-	run()
-	wasmNested = false
-}
-
 var handleEvent func()
 
 //go:linkname setEventHandler syscall/js.setEventHandler
@@ -44,8 +27,12 @@ func nanosecondsToTicks(ns int64) timeUnit {
 // This function is called by the scheduler.
 // Schedule a call to runtime.scheduler, do not actually sleep.
 //
-//export runtime.sleepTicks
+//go:wasmimport gojs runtime.sleepTicks
 func sleepTicks(d timeUnit)
 
-//export runtime.ticks
+//go:wasmimport gojs runtime.ticks
 func ticks() timeUnit
+
+func beforeExit() {
+	__stdio_exit()
+}
