@@ -1,4 +1,4 @@
-//go:build wasi || wasip1
+//go:build wasip1 || wasip2
 
 package syscall
 
@@ -70,9 +70,10 @@ const (
 	__WASI_FILETYPE_SYMBOLIC_LINK    = 7
 
 	// ../../lib/wasi-libc/libc-bottom-half/headers/public/__header_fcntl.h
-	O_RDONLY = 0x04000000
-	O_WRONLY = 0x10000000
-	O_RDWR   = O_RDONLY | O_WRONLY
+	O_NOFOLLOW = 0x01000000
+	O_RDONLY   = 0x04000000
+	O_WRONLY   = 0x10000000
+	O_RDWR     = O_RDONLY | O_WRONLY
 
 	O_CREAT     = __WASI_OFLAGS_CREAT << 12
 	O_TRUNC     = __WASI_OFLAGS_TRUNC << 12
@@ -103,6 +104,9 @@ const (
 	// ../../lib/wasi-libc/expected/wasm32-wasi/predefined-macros.txt
 	F_GETFL = 3
 	F_SETFL = 4
+
+	// ../../lib/wasi-libc/libc-top-half/musl/arch/generic/bits/ioctl.h
+	TIOCSPGRP = 0x5410
 )
 
 // These values are needed as a stub until Go supports WASI as a full target.
@@ -113,16 +117,15 @@ const (
 	SYS_FCNTL
 	SYS_FCNTL64
 	SYS_FSTATAT64
+	SYS_IOCTL
 	SYS_OPENAT
 	SYS_UNLINKAT
 	PATH_MAX = 4096
 )
 
-//go:extern errno
-var libcErrno uintptr
-
 func getErrno() error {
-	return Errno(libcErrno)
+	// libcErrno is the errno from wasi-libc for wasip1 and the errno for libc_wasip2 for wasip2
+	return libcErrno
 }
 
 func (e Errno) Is(target error) bool {
@@ -195,6 +198,7 @@ const (
 	ENOTCONN        Errno = 53         /* Socket is not connected */
 	ENOTDIR         Errno = 54         /* Not a directory */
 	ENOTEMPTY       Errno = 55         /* Directory not empty */
+	ENOTRECOVERABLE Errno = 56         /* State not recoverable */
 	ENOTSOCK        Errno = 57         /* Socket operation on non-socket */
 	ESOCKTNOSUPPORT Errno = 58         /* Socket type not supported */
 	EOPNOTSUPP      Errno = 58         /* Operation not supported on transport endpoint */
@@ -213,10 +217,15 @@ const (
 	ESRCH           Errno = 71         /* No such process */
 	ESTALE          Errno = 72
 	ETIMEDOUT       Errno = 73 /* Connection timed out */
+	ETXTBSY         Errno = 74 /* Text file busy */
 	EXDEV           Errno = 75 /* Cross-device link */
 	ENOTCAPABLE     Errno = 76 /* Extension: Capabilities insufficient. */
+
+	EWASIERROR Errno = 255 /* Unknown WASI error */
 )
 
+// TODO(ydnar): remove Timespec for WASI Preview 2 (seconds is uint64).
+//
 // https://github.com/WebAssembly/wasi-libc/blob/main/libc-bottom-half/headers/public/__struct_timespec.h
 type Timespec struct {
 	Sec  int32
@@ -344,7 +353,7 @@ func Fdclosedir(dir uintptr) (err error) {
 func Readdir(dir uintptr) (dirent *Dirent, err error) {
 	// There might be a leftover errno value in the global variable, so we have
 	// to clear it before calling readdir because we cannot know whether a nil
-	// return means that we reached EOF or that an error occured.
+	// return means that we reached EOF or that an error occurred.
 	libcErrno = 0
 
 	dirent = libc_readdir(unsafe.Pointer(dir))
@@ -397,6 +406,7 @@ func Chmod(path string, mode uint32) (err error) {
 	return Lstat(path, &stat)
 }
 
+// TODO: should this return runtime.wasmPageSize?
 func Getpagesize() int {
 	return libc_getpagesize()
 }
@@ -410,6 +420,11 @@ type Utsname struct {
 	Domainname [65]int8
 }
 
+//go:linkname faccessat syscall.Faccessat
+func faccessat(dirfd int, path string, mode uint32, flags int) (err error) {
+	return ENOSYS
+}
+
 // Stub Utsname, needed because WASI pretends to be linux/arm.
 func Uname(buf *Utsname) (err error)
 
